@@ -5,11 +5,10 @@ from strawberry.dataloader import DataLoader
 from typing_extensions import TypeAlias
 
 from phoenix.db import models
-from phoenix.server.api.types.Evaluation import DocumentAnnotation
 from phoenix.server.types import DbSessionFactory
 
 Key: TypeAlias = int
-Result: TypeAlias = list[DocumentAnnotation]
+Result: TypeAlias = list[models.DocumentAnnotation]
 
 
 class DocumentEvaluationsDataLoader(DataLoader[Key, Result]):
@@ -18,14 +17,12 @@ class DocumentEvaluationsDataLoader(DataLoader[Key, Result]):
         self._db = db
 
     async def _load_fn(self, keys: list[Key]) -> list[Result]:
-        document_evaluations_by_id: defaultdict[Key, Result] = defaultdict(list)
+        document_annotations_by_id: defaultdict[Key, Result] = defaultdict(list)
         mda = models.DocumentAnnotation
         async with self._db() as session:
-            data = await session.stream_scalars(
-                select(mda).where(mda.span_rowid.in_(keys)).where(mda.annotator_kind == "LLM")
-            )
+            data = await session.stream_scalars(select(mda).where(mda.span_rowid.in_(keys)))
             async for document_evaluation in data:
-                document_evaluations_by_id[document_evaluation.span_rowid].append(
-                    DocumentAnnotation.from_sql_document_annotation(document_evaluation)
+                document_annotations_by_id[document_evaluation.span_rowid].append(
+                    document_evaluation
                 )
-        return [document_evaluations_by_id[key] for key in keys]
+        return [document_annotations_by_id[key] for key in keys]
