@@ -1,4 +1,5 @@
 import json
+import logging
 from collections import defaultdict
 from collections.abc import Mapping
 from dataclasses import asdict
@@ -54,6 +55,8 @@ ChatCompletionMessage: TypeAlias = tuple[
 ]
 ToolCallID: TypeAlias = str
 
+logger = logging.getLogger(__name__)
+
 
 class streaming_llm_span:
     """
@@ -117,6 +120,7 @@ class streaming_llm_span:
                     exception_stacktrace=format_exc(),
                 )
             )
+            logger.exception(exc_value)
         if self._text_chunks or self._tool_call_chunks:
             self._attributes.update(
                 chain(
@@ -259,10 +263,13 @@ def llm_tools(tools: list[JSONScalarType]) -> Iterator[tuple[str, Any]]:
 def input_value_and_mime_type(
     input: Union[ChatCompletionInput, ChatCompletionOverDatasetInput],
 ) -> Iterator[tuple[str, Any]]:
-    assert (api_key := "api_key") in (input_data := jsonify(input))
-    disallowed_keys = {"api_key", "invocation_parameters"}
+    input_data = jsonify(input)
+    # Filter out sensitive credential information and invocation parameters
+    disallowed_keys = {"api_key", "credentials", "invocation_parameters"}
     input_data = {k: v for k, v in input_data.items() if k not in disallowed_keys}
-    assert api_key not in input_data
+    # Ensure sensitive data is not included in trace data
+    assert "api_key" not in input_data
+    assert "credentials" not in input_data
     yield INPUT_MIME_TYPE, JSON
     yield INPUT_VALUE, safe_json_dumps(input_data)
 
